@@ -1,4 +1,4 @@
 from palm_rlhf_pytorch.palm import PaLM
 from palm_rlhf_pytorch.palm_enc_dec import PaLMEncDec
 from palm_rlhf_pytorch.reward import RewardModel
-from palm_rlhf_pytorch.ppo import RLHFTrainer, ActorCritic
+from palm_rlhf_pytorch.ppo import RLHFTrainer, ActorCritic, ActorCriticEncDec
