@@ -30,7 +30,7 @@ from accelerate import Accelerator
 
 # actor critic - PaLM with lora
 
-PPOActionCriticReturn = namedtuple('PPOActionCriticReturn', [
+PPOActorCriticReturn = namedtuple('PPOActorCriticReturn', [
     'state',
     'actions',
     'sequence',
@@ -146,7 +146,7 @@ class ActorCritic(nn.Module):
             return_last_n_tokens = action_len
         )
 
-        return PPOActionCriticReturn(
+        return PPOActorCriticReturn(
             state,
             actions,
             sequence,
@@ -293,7 +293,7 @@ class ActorCriticEncDec(nn.Module):
             return_values = return_values
         )
 
-        return PPOActionCriticReturn(
+        return PPOActorCriticReturn(
             state,
             actions,
             sequence,
@@ -772,7 +772,6 @@ class RLHFTrainer(nn.Module):
                 action_prob = action_logits.softmax(dim = -1)
                 action_log_prob = log_prob(action_prob, actions)
 
-
                 # get reward as given by supervised trained reward model
 
                 sequence = torch.cat((states, actions), dim = -1)
